"""Choice variables used by Societies"""

BLOODGROUPS = [
    (0, "Unspecified"),
    (1, "A+"),
    (2, "A-"),
    (3, "B+"),
    (4, "B-"),
    (5, "O+"),
    (6, "O-"),
    (7, "AB+"),
    (8, "AB-"),
]

EVENT_PROOFS = [
    (0, "Unspecified"),
    (1, "Certificate"),
    (2, "Letter"),
    (3, "Receipt"),
    (4, "Poster/Card"),
]

EVENT_TYPES = [
    (0, "Unspecified"),
    (1, "Birthday"),
    (2, "Graduation"),
    (3, "Award"),
    (4, "Certification"),
    (5, "Marriage"),
    (6, "Appointment"),
    (7, "Election"),
    (8, "Travel"),
    (9, "Accident"),
    (10, "Examination"),
    (11, "Anniversary"),
    (12, "Admission"),
    (13, "Promotion"),
    (14, "Resignation"),
    (15, "Transfer"),
    (16, "Vacation"),
    (17, "Illness"),
    (18, "Deferment"),
    (20, "Suspension"),
    (21, "Expulsion"),
    (22, "Assault"),
    (23, "Excursion"),
    (24, "Faculty Week"),
    (25, "Student-Body Week"),
    (26, "Conference"),
    (27, "Meeting"),
    (28, "Education/Study"),
]

GENOTYPES = [
    (0, "Unspecified"),
    (1, "AA"),
    (2, "AS"),
    (3, "AC"),
    (4, "SS"),
    (5, "SC"),
    (6, "CC"),
]

HONORIFICS = [
    ("Master", "Master"),
    ("Mr", "Mister"),
    ("Ms", "Miss"),
    ("Mrs", "Missus"),
    ("Mx", "Mx"),
    ("Sir", "Sir"),
    ("Sire", "Sire"),
    ("Ma'am", "Madam"),
    ("Dame", "Dame"),
    ("Lord", "Lord"),
    ("Lady", "Lady"),
    ("Esq", "Esquire"),
    ("Hon.", "Honorable"),
    ("Excellency", "Excellency"),
    ("Rt Hon.", "The Right Honorable"),
    ("Dr", "Doctor"),
    ("Prof", "Professor"),
    ("Arc.", "Architect"),
    ("Bldr.", "Builder"),
    ("Engr.", "Engineer"),
    ("Rev.", "Reverend"),
    ("Chief", "Chief"),
    ("H.R.H. Igwe", "His Royal Highness"),
    ("Surv.", "Surveyor"),
    ("Mr & Mrs", "Mister and Missus"),
    ("Elder", "Elder"),
    ("Ven.", "Venerable"),
    ("Bishop", "Bishop"),
    ("Pastor", "Pastor"),
    ("Barr.", "Barrister"),
    ("Hon. Barr.", "Honorable Barrister"),
    ("High Chief", "High Chief"),
]

LOCATION_COUNTRIES = [
    ("AF", "Afghanistan"),
    ("AX", "Aland Islands"),
    ("AL", "Albania"),
    ("DZ", "Algeria"),
    ("AS", "American Samoa"),
    ("AD", "Andorra"),
    ("AO", "Angola"),
    ("AI", "Anguilla"),
    ("AQ", "Antarctica"),
    ("AG", "Antigua And Barbuda"),
    ("AR", "Argentina"),
    ("AM", "Armenia"),
    ("AW", "Aruba"),
    ("AU", "Australia"),
    ("AT", "Austria"),
    ("AZ", "Azerbaijan"),
    ("BH", "Bahrain"),
    ("BD", "Bangladesh"),
    ("BB", "Barbados"),
    ("BY", "Belarus"),
    ("BE", "Belgium"),
    ("BZ", "Belize"),
    ("BJ", "Benin"),
    ("BM", "Bermuda"),
    ("BT", "Bhutan"),
    ("BO", "Bolivia"),
    ("BQ", "Bonaire, Sint Eustatius and Saba"),
    ("BA", "Bosnia and Herzegovina"),
    ("BW", "Botswana"),
    ("BV", "Bouvet Island"),
    ("BR", "Brazil"),
    ("IO", "British Indian Ocean Territory"),
    ("BN", "Brunei"),
    ("BG", "Bulgaria"),
    ("BF", "Burkina Faso"),
    ("BI", "Burundi"),
    ("KH", "Cambodia"),
    ("CM", "Cameroon"),
    ("CA", "Canada"),
    ("CV", "Cape Verde"),
    ("KY", "Cayman Islands"),
    ("CF", "Central African Republic"),
    ("TD", "Chad"),
    ("CL", "Chile"),
    ("CN", "China"),
    ("CX", "Christmas Island"),
    ("CC", "Cocos (Keeling) Islands"),
    ("CO", "Colombia"),
    ("KM", "Comoros"),
    ("CG", "Congo"),
    ("CK", "Cook Islands"),
    ("CR", "Costa Rica"),
    ("CI", "Cote D'Ivoire (Ivory Coast)"),
    ("HR", "Croatia"),
    ("CU", "Cuba"),
    ("CW", "Curaçao"),
    ("CY", "Cyprus"),
    ("CZ", "Czech Republic"),
    ("CD", "Democratic Republic of the Congo"),
    ("DK", "Denmark"),
    ("DJ", "Djibouti"),
    ("DM", "Dominica"),
    ("DO", "Dominican Republic"),
    ("TL", "East Timor"),
    ("EC", "Ecuador"),
    ("EG", "Egypt"),
    ("SV", "El Salvador"),
    ("GQ", "Equatorial Guinea"),
    ("ER", "Eritrea"),
    ("EE", "Estonia"),
    ("ET", "Ethiopia"),
    ("FK", "Falkland Islands"),
    ("FO", "Faroe Islands"),
    ("FJ", "Fiji Islands"),
    ("FI", "Finland"),
    ("FR", "France"),
    ("GF", "French Guiana"),
    ("PF", "French Polynesia"),
    ("TF", "French Southern Territories"),
    ("GA", "Gabon"),
    ("GM", "Gambia The"),
    ("GE", "Georgia"),
    ("DE", "Germany"),
    ("GH", "Ghana"),
    ("GI", "Gibraltar"),
    ("GR", "Greece"),
    ("GL", "Greenland"),
    ("GD", "Grenada"),
    ("GP", "Guadeloupe"),
    ("GU", "Guam"),
    ("GT", "Guatemala"),
    ("GG", "Guernsey and Alderney"),
    ("GN", "Guinea"),
    ("GW", "Guinea-Bissau"),
    ("GY", "Guyana"),
    ("HT", "Haiti"),
    ("HM", "Heard Island and McDonald Islands"),
    ("HN", "Honduras"),
    ("HK", "Hong Kong S.A.R."),
    ("HU", "Hungary"),
    ("IS", "Iceland"),
    ("IN", "India"),
    ("ID", "Indonesia"),
    ("IR", "Iran"),
    ("IQ", "Iraq"),
    ("IE", "Ireland"),
    ("IL", "Israel"),
    ("IT", "Italy"),
    ("JM", "Jamaica"),
    ("JP", "Japan"),
    ("JE", "Jersey"),
    ("JO", "Jordan"),
    ("KZ", "Kazakhstan"),
    ("KE", "Kenya"),
    ("KI", "Kiribati"),
    ("XK", "Kosovo"),
    ("KW", "Kuwait"),
    ("KG", "Kyrgyzstan"),
    ("LA", "Laos"),
    ("LV", "Latvia"),
    ("LB", "Lebanon"),
    ("LS", "Lesotho"),
    ("LR", "Liberia"),
    ("LY", "Libya"),
    ("LI", "Liechtenstein"),
    ("LT", "Lithuania"),
    ("LU", "Luxembourg"),
    ("MO", "Macau S.A.R."),
    ("MG", "Madagascar"),
    ("MW", "Malawi"),
    ("MY", "Malaysia"),
    ("MV", "Maldives"),
    ("ML", "Mali"),
    ("MT", "Malta"),
    ("IM", "Man (Isle of)"),
    ("MH", "Marshall Islands"),
    ("MQ", "Martinique"),
    ("MR", "Mauritania"),
    ("MU", "Mauritius"),
    ("YT", "Mayotte"),
    ("MX", "Mexico"),
    ("FM", "Micronesia"),
    ("MD", "Moldova"),
    ("MC", "Monaco"),
    ("MN", "Mongolia"),
    ("ME", "Montenegro"),
    ("MS", "Montserrat"),
    ("MA", "Morocco"),
    ("MZ", "Mozambique"),
    ("MM", "Myanmar"),
    ("NA", "Namibia"),
    ("NR", "Nauru"),
    ("NP", "Nepal"),
    ("NL", "Netherlands"),
    ("NC", "New Caledonia"),
    ("NZ", "New Zealand"),
    ("NI", "Nicaragua"),
    ("NE", "Niger"),
    ("NG", "Nigeria"),
    ("NU", "Niue"),
    ("NF", "Norfolk Island"),
    ("KP", "North Korea"),
    ("MK", "North Macedonia"),
    ("MP", "Northern Mariana Islands"),
    ("NO", "Norway"),
    ("OM", "Oman"),
    ("PK", "Pakistan"),
    ("PW", "Palau"),
    ("PS", "Palestinian Territory Occupied"),
    ("PA", "Panama"),
    ("PG", "Papua new Guinea"),
    ("PY", "Paraguay"),
    ("PE", "Peru"),
    ("PH", "Philippines"),
    ("PN", "Pitcairn Island"),
    ("PL", "Poland"),
    ("PT", "Portugal"),
    ("PR", "Puerto Rico"),
    ("QA", "Qatar"),
    ("RE", "Reunion"),
    ("RO", "Romania"),
    ("RU", "Russia"),
    ("RW", "Rwanda"),
    ("SH", "Saint Helena"),
    ("KN", "Saint Kitts And Nevis"),
    ("LC", "Saint Lucia"),
    ("PM", "Saint Pierre and Miquelon"),
    ("VC", "Saint Vincent And The Grenadines"),
    ("BL", "Saint-Barthelemy"),
    ("MF", "Saint-Martin (French part)"),
    ("WS", "Samoa"),
    ("SM", "San Marino"),
    ("ST", "Sao Tome and Principe"),
    ("SA", "Saudi Arabia"),
    ("SN", "Senegal"),
    ("RS", "Serbia"),
    ("SC", "Seychelles"),
    ("SL", "Sierra Leone"),
    ("SG", "Singapore"),
    ("SX", "Sint Maarten (Dutch part)"),
    ("SK", "Slovakia"),
    ("SI", "Slovenia"),
    ("SB", "Solomon Islands"),
    ("SO", "Somalia"),
    ("ZA", "South Africa"),
    ("GS", "South Georgia"),
    ("KR", "South Korea"),
    ("SS", "South Sudan"),
    ("ES", "Spain"),
    ("LK", "Sri Lanka"),
    ("SD", "Sudan"),
    ("SR", "Suriname"),
    ("SJ", "Svalbard And Jan Mayen Islands"),
    ("SZ", "Swaziland"),
    ("SE", "Sweden"),
    ("CH", "Switzerland"),
    ("SY", "Syria"),
    ("TW", "Taiwan"),
    ("TJ", "Tajikistan"),
    ("TZ", "Tanzania"),
    ("TH", "Thailand"),
    ("BS", "The Bahamas"),
    ("TG", "Togo"),
    ("TK", "Tokelau"),
    ("TO", "Tonga"),
    ("TT", "Trinidad And Tobago"),
    ("TN", "Tunisia"),
    ("TR", "Turkey"),
    ("TM", "Turkmenistan"),
    ("TC", "Turks And Caicos Islands"),
    ("TV", "Tuvalu"),
    ("UG", "Uganda"),
    ("UA", "Ukraine"),
    ("AE", "United Arab Emirates"),
    ("GB", "United Kingdom"),
    ("US", "United States"),
    ("UM", "United States Minor Outlying Islands"),
    ("UY", "Uruguay"),
    ("UZ", "Uzbekistan"),
    ("VU", "Vanuatu"),
    ("VA", "Vatican City State (Holy See)"),
    ("VE", "Venezuela"),
    ("VN", "Vietnam"),
    ("VG", "Virgin Islands (British)"),
    ("VI", "Virgin Islands (US)"),
    ("WF", "Wallis And Futuna Islands"),
    ("EH", "Western Sahara"),
    ("YE", "Yemen"),
    ("ZM", "Zambia"),
    ("ZW", "Zimbabwe"),
]

LOCATION_TYPES = [
    (1, "Home"),
    (2, "Work"),
    (3, "Permanent"),
    (4, "Mobile"),
    (5, "Emergency"),
    (6, "Other"),
]

MARITALSTATUS = [
    (1, "Single"),
    (2, "Married"),
]

RELIGIONS = [
    (0, "Unspecified"),
    (1, "African Diaspora Religions"),
    (2, "Atheism/Agnosticism"),
    (3, "Bahá’í"),
    (4, "Buddhism"),
    (5, "Christianity"),
    (6, "Confucianism"),
    (7, "Druze"),
    (8, "Gnosticism"),
    (9, "Hinduism"),
    (10, "Indigenous American Religions"),
    (11, "Islam"),
    (12, "Jainism"),
    (13, "Judaism"),
    (14, "Rastafarianism"),
    (15, "Shinto"),
    (16, "Sikhism"),
    (17, "Traditional African Religions"),
    (18, "Zoroastrianism"),
]

SEXES = [
    (0, "Unspecified"),
    (1, "Male"),
    (2, "Female"),
]

TIES = [
    (0, "Unspecified"),
    (1, "Father"),
    (2, "Mother"),
    (3, "Brother"),
    (4, "Sister"),
    (5, "Cousin"),
    (6, "Nephew"),
    (7, "Niece"),
    (8, "Uncle"),
    (9, "Aunt"),
    (10, "Parent"),
    (11, "Father-in-Law"),
    (12, "Mother-in-Law"),
    (13, "Son-in-Law"),
    (14, "Daughter-in-Law"),
    (15, "Brother-in-Law"),
    (16, "Sister-in-Law"),
    (17, "Husband"),
    (18, "Wife"),
    (19, "Spouse"),
    (20, "Son"),
    (21, "Daughter"),
    (22, "Self"),
    (23, "Pastor"),
    (24, "Priest"),
    (25, "Local Ordinary"),
    (26, "Employer"),
    (27, "Non-Profit Organization"),
    (28, "Corporate Sponsor"),
    (29, "Group Sponsor"),
]
